
# Type: subsets


list of subsets referenced in this model

URI: [meta:subsets](https://w3id.org/biolink/biolinkml/meta/subsets)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>0..*</sub> [SubsetDefinition](SubsetDefinition.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
